package com.yinet.bjtj.service;

import com.yinet.bjtj.domain.FormBjtj;

import java.util.List;
import java.util.Map;

/**
 * 办件统计Service接口
 * 
 * @author yinet
 * @date 2020-04-02
 */
public interface IFormBjtjService 
{
    /**
     * 查询办件统计
     * 
     * @param id 办件统计ID
     * @return 办件统计
     */
    public FormBjtj selectFormBjtjById(Long id);

    /**
     * 查询办件统计列表
     * 
     * @param formBjtj 办件统计
     * @return 办件统计集合
     */
    public List<FormBjtj> selectFormBjtjList(FormBjtj formBjtj);

    /**
     * 新增办件统计
     * 
     * @param formBjtj 办件统计
     * @return 结果
     */
    public int insertFormBjtj(FormBjtj formBjtj);

    /**
     * 修改办件统计
     * 
     * @param formBjtj 办件统计
     * @return 结果
     */
    public int updateFormBjtj(FormBjtj formBjtj);

    /**
     * 批量删除办件统计
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteFormBjtjByIds(String ids);

    /**
     * 删除办件统计信息
     * 
     * @param id 办件统计ID
     * @return 结果
     */
    public int deleteFormBjtjById(Long id);
    /**
     * 查询办件统计列表(前台页面)
     *
     * @return 办件统计
     */
    public Map selectTongjiList();
    /** 查询当月统计数量**/
    public Map<String, Object> selectFormBjtjVoCountByConditiond(Map<String, Object> map);
    /** 查询当年每月统计数量
     * @return**/
    public   List<Map<String, Integer>>  selectFormBjtjByMonthes();


}
